# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GitxWebhookArgs', 'GitxWebhook']

@pulumi.input_type
class GitxWebhookArgs:
    def __init__(__self__, *,
                 connector_ref: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 repo_name: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_paths: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a GitxWebhook resource.
        :param pulumi.Input[_builtins.str] connector_ref: ConnectorRef to be used to create Gitx webhook.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] repo_name: Repo Identifier for Gitx webhook.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] folder_paths: Folder Paths
        :param pulumi.Input[_builtins.bool] is_enabled: Flag to enable the webhook
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "connector_ref", connector_ref)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "repo_name", repo_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if folder_paths is not None:
            pulumi.set(__self__, "folder_paths", folder_paths)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="connectorRef")
    def connector_ref(self) -> pulumi.Input[_builtins.str]:
        """
        ConnectorRef to be used to create Gitx webhook.
        """
        return pulumi.get(self, "connector_ref")

    @connector_ref.setter
    def connector_ref(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "connector_ref", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> pulumi.Input[_builtins.str]:
        """
        Repo Identifier for Gitx webhook.
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repo_name", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="folderPaths")
    def folder_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Folder Paths
        """
        return pulumi.get(self, "folder_paths")

    @folder_paths.setter
    def folder_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "folder_paths", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to enable the webhook
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _GitxWebhookState:
    def __init__(__self__, *,
                 connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_paths: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering GitxWebhook resources.
        :param pulumi.Input[_builtins.str] connector_ref: ConnectorRef to be used to create Gitx webhook.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] folder_paths: Folder Paths
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_enabled: Flag to enable the webhook
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_name: Repo Identifier for Gitx webhook.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if connector_ref is not None:
            pulumi.set(__self__, "connector_ref", connector_ref)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if folder_paths is not None:
            pulumi.set(__self__, "folder_paths", folder_paths)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_name is not None:
            pulumi.set(__self__, "repo_name", repo_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="connectorRef")
    def connector_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ConnectorRef to be used to create Gitx webhook.
        """
        return pulumi.get(self, "connector_ref")

    @connector_ref.setter
    def connector_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connector_ref", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="folderPaths")
    def folder_paths(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Folder Paths
        """
        return pulumi.get(self, "folder_paths")

    @folder_paths.setter
    def folder_paths(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "folder_paths", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to enable the webhook
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repo Identifier for Gitx webhook.
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/gitxWebhook:GitxWebhook")
class GitxWebhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_paths: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness GitX Webhook.

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>
        ```

        Import an Org level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>/<org_id>/
        ```

        Import a Project level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>/<org_id>/<project_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] connector_ref: ConnectorRef to be used to create Gitx webhook.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] folder_paths: Folder Paths
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_enabled: Flag to enable the webhook
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_name: Repo Identifier for Gitx webhook.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GitxWebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness GitX Webhook.

        ## Import

        The `pulumi import` command can be used, for example:

        Import an Account level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>
        ```

        Import an Org level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>/<org_id>/
        ```

        Import a Project level Webhook

        ```sh
        $ pulumi import harness:platform/gitxWebhook:GitxWebhook example <webhook_identifier>/<org_id>/<project_id>
        ```

        :param str resource_name: The name of the resource.
        :param GitxWebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GitxWebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_paths: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GitxWebhookArgs.__new__(GitxWebhookArgs)

            if connector_ref is None and not opts.urn:
                raise TypeError("Missing required property 'connector_ref'")
            __props__.__dict__["connector_ref"] = connector_ref
            __props__.__dict__["description"] = description
            __props__.__dict__["folder_paths"] = folder_paths
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if repo_name is None and not opts.urn:
                raise TypeError("Missing required property 'repo_name'")
            __props__.__dict__["repo_name"] = repo_name
            __props__.__dict__["tags"] = tags
        super(GitxWebhook, __self__).__init__(
            'harness:platform/gitxWebhook:GitxWebhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            folder_paths: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'GitxWebhook':
        """
        Get an existing GitxWebhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] connector_ref: ConnectorRef to be used to create Gitx webhook.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] folder_paths: Folder Paths
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_enabled: Flag to enable the webhook
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_name: Repo Identifier for Gitx webhook.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GitxWebhookState.__new__(_GitxWebhookState)

        __props__.__dict__["connector_ref"] = connector_ref
        __props__.__dict__["description"] = description
        __props__.__dict__["folder_paths"] = folder_paths
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repo_name"] = repo_name
        __props__.__dict__["tags"] = tags
        return GitxWebhook(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="connectorRef")
    def connector_ref(self) -> pulumi.Output[_builtins.str]:
        """
        ConnectorRef to be used to create Gitx webhook.
        """
        return pulumi.get(self, "connector_ref")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="folderPaths")
    def folder_paths(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Folder Paths
        """
        return pulumi.get(self, "folder_paths")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to enable the webhook
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> pulumi.Output[_builtins.str]:
        """
        Repo Identifier for Gitx webhook.
        """
        return pulumi.get(self, "repo_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IdpEnvironmentBlueprintArgs', 'IdpEnvironmentBlueprint']

@pulumi.input_type
class IdpEnvironmentBlueprintArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 version: pulumi.Input[_builtins.str],
                 yaml: pulumi.Input[_builtins.str],
                 deprecated: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 stable: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a IdpEnvironmentBlueprint resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] version: Version of the catalog entity
        :param pulumi.Input[_builtins.str] yaml: YAML definition of the catalog entity
        :param pulumi.Input[_builtins.bool] deprecated: Whether the catalog entity is deprecated
        :param pulumi.Input[_builtins.str] description: Description of the catalog entity
        :param pulumi.Input[_builtins.bool] stable: Whether the catalog entity is stable
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "version", version)
        pulumi.set(__self__, "yaml", yaml)
        if deprecated is not None:
            pulumi.set(__self__, "deprecated", deprecated)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if stable is not None:
            pulumi.set(__self__, "stable", stable)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        Version of the catalog entity
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Input[_builtins.str]:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "yaml", value)

    @_builtins.property
    @pulumi.getter
    def deprecated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the catalog entity is deprecated
        """
        return pulumi.get(self, "deprecated")

    @deprecated.setter
    def deprecated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deprecated", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the catalog entity
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def stable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the catalog entity is stable
        """
        return pulumi.get(self, "stable")

    @stable.setter
    def stable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stable", value)


@pulumi.input_type
class _IdpEnvironmentBlueprintState:
    def __init__(__self__, *,
                 deprecated: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IdpEnvironmentBlueprint resources.
        :param pulumi.Input[_builtins.bool] deprecated: Whether the catalog entity is deprecated
        :param pulumi.Input[_builtins.str] description: Description of the catalog entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] stable: Whether the catalog entity is stable
        :param pulumi.Input[_builtins.str] version: Version of the catalog entity
        :param pulumi.Input[_builtins.str] yaml: YAML definition of the catalog entity
        """
        if deprecated is not None:
            pulumi.set(__self__, "deprecated", deprecated)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if stable is not None:
            pulumi.set(__self__, "stable", stable)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def deprecated(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the catalog entity is deprecated
        """
        return pulumi.get(self, "deprecated")

    @deprecated.setter
    def deprecated(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deprecated", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the catalog entity
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def stable(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the catalog entity is stable
        """
        return pulumi.get(self, "stable")

    @stable.setter
    def stable(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stable", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Version of the catalog entity
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/idpEnvironmentBlueprint:IdpEnvironmentBlueprint")
class IdpEnvironmentBlueprint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deprecated: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating IDP environment blueprints.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironmentBlueprint("test",
            identifier="identifier",
            version="v1.0.0",
            stable=True,
            deprecated=False,
            description="description",
            yaml=\"\"\"apiVersion: harness.io/v1
        kind: EnvironmentBlueprint
        type: long-lived
        identifier: identifier
        name: name
        owner: group:account/_account_all_users
        metadata:
          description: description
        spec:
          entities:
          - identifier: git
            backend:
              type: HarnessCD
              steps:
                apply:
                  pipeline: gittest
                  branch: main
                destroy:
                  pipeline: gittest
                  branch: not-main
          ownedBy:
          - group:account/_account_all_users
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment blueprint

        ```sh
        $ pulumi import harness:platform/idpEnvironmentBlueprint:IdpEnvironmentBlueprint example <blueprint_id>/<version>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] deprecated: Whether the catalog entity is deprecated
        :param pulumi.Input[_builtins.str] description: Description of the catalog entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] stable: Whether the catalog entity is stable
        :param pulumi.Input[_builtins.str] version: Version of the catalog entity
        :param pulumi.Input[_builtins.str] yaml: YAML definition of the catalog entity
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IdpEnvironmentBlueprintArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating IDP environment blueprints.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.IdpEnvironmentBlueprint("test",
            identifier="identifier",
            version="v1.0.0",
            stable=True,
            deprecated=False,
            description="description",
            yaml=\"\"\"apiVersion: harness.io/v1
        kind: EnvironmentBlueprint
        type: long-lived
        identifier: identifier
        name: name
        owner: group:account/_account_all_users
        metadata:
          description: description
        spec:
          entities:
          - identifier: git
            backend:
              type: HarnessCD
              steps:
                apply:
                  pipeline: gittest
                  branch: main
                destroy:
                  pipeline: gittest
                  branch: not-main
          ownedBy:
          - group:account/_account_all_users
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import environment blueprint

        ```sh
        $ pulumi import harness:platform/idpEnvironmentBlueprint:IdpEnvironmentBlueprint example <blueprint_id>/<version>
        ```

        :param str resource_name: The name of the resource.
        :param IdpEnvironmentBlueprintArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdpEnvironmentBlueprintArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deprecated: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 stable: Optional[pulumi.Input[_builtins.bool]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdpEnvironmentBlueprintArgs.__new__(IdpEnvironmentBlueprintArgs)

            __props__.__dict__["deprecated"] = deprecated
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["stable"] = stable
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            if yaml is None and not opts.urn:
                raise TypeError("Missing required property 'yaml'")
            __props__.__dict__["yaml"] = yaml
        super(IdpEnvironmentBlueprint, __self__).__init__(
            'harness:platform/idpEnvironmentBlueprint:IdpEnvironmentBlueprint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deprecated: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            stable: Optional[pulumi.Input[_builtins.bool]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'IdpEnvironmentBlueprint':
        """
        Get an existing IdpEnvironmentBlueprint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] deprecated: Whether the catalog entity is deprecated
        :param pulumi.Input[_builtins.str] description: Description of the catalog entity
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] stable: Whether the catalog entity is stable
        :param pulumi.Input[_builtins.str] version: Version of the catalog entity
        :param pulumi.Input[_builtins.str] yaml: YAML definition of the catalog entity
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdpEnvironmentBlueprintState.__new__(_IdpEnvironmentBlueprintState)

        __props__.__dict__["deprecated"] = deprecated
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["stable"] = stable
        __props__.__dict__["version"] = version
        __props__.__dict__["yaml"] = yaml
        return IdpEnvironmentBlueprint(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def deprecated(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the catalog entity is deprecated
        """
        return pulumi.get(self, "deprecated")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the catalog entity
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def stable(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the catalog entity is stable
        """
        return pulumi.get(self, "stable")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        Version of the catalog entity
        """
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        YAML definition of the catalog entity
        """
        return pulumi.get(self, "yaml")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DelegateApprovalArgs', 'DelegateApproval']

@pulumi.input_type
class DelegateApprovalArgs:
    def __init__(__self__, *,
                 approve: pulumi.Input[_builtins.bool],
                 delegate_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a DelegateApproval resource.
        :param pulumi.Input[_builtins.bool] approve: Whether or not to approve the delegate.
        :param pulumi.Input[_builtins.str] delegate_id: The id of the delegate.
        """
        pulumi.set(__self__, "approve", approve)
        pulumi.set(__self__, "delegate_id", delegate_id)

    @_builtins.property
    @pulumi.getter
    def approve(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether or not to approve the delegate.
        """
        return pulumi.get(self, "approve")

    @approve.setter
    def approve(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "approve", value)

    @_builtins.property
    @pulumi.getter(name="delegateId")
    def delegate_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the delegate.
        """
        return pulumi.get(self, "delegate_id")

    @delegate_id.setter
    def delegate_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "delegate_id", value)


@pulumi.input_type
class _DelegateApprovalState:
    def __init__(__self__, *,
                 approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 delegate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DelegateApproval resources.
        :param pulumi.Input[_builtins.bool] approve: Whether or not to approve the delegate.
        :param pulumi.Input[_builtins.str] delegate_id: The id of the delegate.
        :param pulumi.Input[_builtins.str] status: The status of the delegate.
        """
        if approve is not None:
            pulumi.set(__self__, "approve", approve)
        if delegate_id is not None:
            pulumi.set(__self__, "delegate_id", delegate_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def approve(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not to approve the delegate.
        """
        return pulumi.get(self, "approve")

    @approve.setter
    def approve(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "approve", value)

    @_builtins.property
    @pulumi.getter(name="delegateId")
    def delegate_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the delegate.
        """
        return pulumi.get(self, "delegate_id")

    @delegate_id.setter
    def delegate_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delegate_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the delegate.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("harness:index/delegateApproval:DelegateApproval")
class DelegateApproval(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 delegate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for approving or rejecting delegates.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.get_delegate(name="my-delegate")
        test_delegate_approval = harness.DelegateApproval("test",
            delegate_id=test.id,
            approve=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import the status of the delegate approval.

        ```sh
        $ pulumi import harness:index/delegateApproval:DelegateApproval example <delegate_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] approve: Whether or not to approve the delegate.
        :param pulumi.Input[_builtins.str] delegate_id: The id of the delegate.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DelegateApprovalArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for approving or rejecting delegates.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.get_delegate(name="my-delegate")
        test_delegate_approval = harness.DelegateApproval("test",
            delegate_id=test.id,
            approve=True)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import the status of the delegate approval.

        ```sh
        $ pulumi import harness:index/delegateApproval:DelegateApproval example <delegate_id>
        ```

        :param str resource_name: The name of the resource.
        :param DelegateApprovalArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DelegateApprovalArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approve: Optional[pulumi.Input[_builtins.bool]] = None,
                 delegate_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DelegateApprovalArgs.__new__(DelegateApprovalArgs)

            if approve is None and not opts.urn:
                raise TypeError("Missing required property 'approve'")
            __props__.__dict__["approve"] = approve
            if delegate_id is None and not opts.urn:
                raise TypeError("Missing required property 'delegate_id'")
            __props__.__dict__["delegate_id"] = delegate_id
            __props__.__dict__["status"] = None
        super(DelegateApproval, __self__).__init__(
            'harness:index/delegateApproval:DelegateApproval',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            approve: Optional[pulumi.Input[_builtins.bool]] = None,
            delegate_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'DelegateApproval':
        """
        Get an existing DelegateApproval resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] approve: Whether or not to approve the delegate.
        :param pulumi.Input[_builtins.str] delegate_id: The id of the delegate.
        :param pulumi.Input[_builtins.str] status: The status of the delegate.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DelegateApprovalState.__new__(_DelegateApprovalState)

        __props__.__dict__["approve"] = approve
        __props__.__dict__["delegate_id"] = delegate_id
        __props__.__dict__["status"] = status
        return DelegateApproval(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def approve(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not to approve the delegate.
        """
        return pulumi.get(self, "approve")

    @_builtins.property
    @pulumi.getter(name="delegateId")
    def delegate_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the delegate.
        """
        return pulumi.get(self, "delegate_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the delegate.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRepoWebhookResult',
    'AwaitableGetRepoWebhookResult',
    'get_repo_webhook',
    'get_repo_webhook_output',
]

@pulumi.output_type
class GetRepoWebhookResult:
    """
    A collection of values returned by getRepoWebhook.
    """
    def __init__(__self__, created=None, created_by=None, description=None, enabled=None, has_secret=None, id=None, identifier=None, insecure=None, org_id=None, project_id=None, repo_identifier=None, secret=None, triggers=None, url=None):
        if created and not isinstance(created, int):
            raise TypeError("Expected argument 'created' to be a int")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, int):
            raise TypeError("Expected argument 'created_by' to be a int")
        pulumi.set(__self__, "created_by", created_by)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if has_secret and not isinstance(has_secret, bool):
            raise TypeError("Expected argument 'has_secret' to be a bool")
        pulumi.set(__self__, "has_secret", has_secret)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if insecure and not isinstance(insecure, bool):
            raise TypeError("Expected argument 'insecure' to be a bool")
        pulumi.set(__self__, "insecure", insecure)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if repo_identifier and not isinstance(repo_identifier, str):
            raise TypeError("Expected argument 'repo_identifier' to be a str")
        pulumi.set(__self__, "repo_identifier", repo_identifier)
        if secret and not isinstance(secret, str):
            raise TypeError("Expected argument 'secret' to be a str")
        pulumi.set(__self__, "secret", secret)
        if triggers and not isinstance(triggers, list):
            raise TypeError("Expected argument 'triggers' to be a list")
        pulumi.set(__self__, "triggers", triggers)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.int:
        """
        Timestamp when the webhook was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.int:
        """
        ID of the user who created the webhook.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Description of the webhook.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Webhook enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="hasSecret")
    def has_secret(self) -> _builtins.bool:
        """
        Created webhook has secret encoding.
        """
        return pulumi.get(self, "has_secret")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the webhook.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def insecure(self) -> _builtins.bool:
        """
        Allow insecure connections for provided webhook URL.
        """
        return pulumi.get(self, "insecure")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> _builtins.str:
        """
        Identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @_builtins.property
    @pulumi.getter
    def secret(self) -> Optional[_builtins.str]:
        """
        Webhook secret which will be used to sign the webhook payload.
        """
        return pulumi.get(self, "secret")

    @_builtins.property
    @pulumi.getter
    def triggers(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of triggers of the webhook (keep empty for all triggers).
        """
        return pulumi.get(self, "triggers")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        URL that's called by the webhook.
        """
        return pulumi.get(self, "url")


class AwaitableGetRepoWebhookResult(GetRepoWebhookResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepoWebhookResult(
            created=self.created,
            created_by=self.created_by,
            description=self.description,
            enabled=self.enabled,
            has_secret=self.has_secret,
            id=self.id,
            identifier=self.identifier,
            insecure=self.insecure,
            org_id=self.org_id,
            project_id=self.project_id,
            repo_identifier=self.repo_identifier,
            secret=self.secret,
            triggers=self.triggers,
            url=self.url)


def get_repo_webhook(description: Optional[_builtins.str] = None,
                     enabled: Optional[_builtins.bool] = None,
                     identifier: Optional[_builtins.str] = None,
                     insecure: Optional[_builtins.bool] = None,
                     org_id: Optional[_builtins.str] = None,
                     project_id: Optional[_builtins.str] = None,
                     repo_identifier: Optional[_builtins.str] = None,
                     secret: Optional[_builtins.str] = None,
                     triggers: Optional[Sequence[_builtins.str]] = None,
                     url: Optional[_builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepoWebhookResult:
    """
    Data source for retrieving a Harness Repo Webhook.


    :param _builtins.str description: Description of the webhook.
    :param _builtins.bool enabled: Webhook enabled.
    :param _builtins.str identifier: Identifier of the webhook.
    :param _builtins.bool insecure: Allow insecure connections for provided webhook URL.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str repo_identifier: Identifier of the repository.
    :param _builtins.str secret: Webhook secret which will be used to sign the webhook payload.
    :param Sequence[_builtins.str] triggers: List of triggers of the webhook (keep empty for all triggers).
    :param _builtins.str url: URL that's called by the webhook.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['enabled'] = enabled
    __args__['identifier'] = identifier
    __args__['insecure'] = insecure
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['repoIdentifier'] = repo_identifier
    __args__['secret'] = secret
    __args__['triggers'] = triggers
    __args__['url'] = url
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getRepoWebhook:getRepoWebhook', __args__, opts=opts, typ=GetRepoWebhookResult).value

    return AwaitableGetRepoWebhookResult(
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        description=pulumi.get(__ret__, 'description'),
        enabled=pulumi.get(__ret__, 'enabled'),
        has_secret=pulumi.get(__ret__, 'has_secret'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        insecure=pulumi.get(__ret__, 'insecure'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        repo_identifier=pulumi.get(__ret__, 'repo_identifier'),
        secret=pulumi.get(__ret__, 'secret'),
        triggers=pulumi.get(__ret__, 'triggers'),
        url=pulumi.get(__ret__, 'url'))
def get_repo_webhook_output(description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                            identifier: Optional[pulumi.Input[_builtins.str]] = None,
                            insecure: Optional[pulumi.Input[_builtins.bool]] = None,
                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                            secret: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            triggers: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                            url: Optional[pulumi.Input[_builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepoWebhookResult]:
    """
    Data source for retrieving a Harness Repo Webhook.


    :param _builtins.str description: Description of the webhook.
    :param _builtins.bool enabled: Webhook enabled.
    :param _builtins.str identifier: Identifier of the webhook.
    :param _builtins.bool insecure: Allow insecure connections for provided webhook URL.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str repo_identifier: Identifier of the repository.
    :param _builtins.str secret: Webhook secret which will be used to sign the webhook payload.
    :param Sequence[_builtins.str] triggers: List of triggers of the webhook (keep empty for all triggers).
    :param _builtins.str url: URL that's called by the webhook.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['enabled'] = enabled
    __args__['identifier'] = identifier
    __args__['insecure'] = insecure
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['repoIdentifier'] = repo_identifier
    __args__['secret'] = secret
    __args__['triggers'] = triggers
    __args__['url'] = url
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getRepoWebhook:getRepoWebhook', __args__, opts=opts, typ=GetRepoWebhookResult)
    return __ret__.apply(lambda __response__: GetRepoWebhookResult(
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        description=pulumi.get(__response__, 'description'),
        enabled=pulumi.get(__response__, 'enabled'),
        has_secret=pulumi.get(__response__, 'has_secret'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        insecure=pulumi.get(__response__, 'insecure'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        repo_identifier=pulumi.get(__response__, 'repo_identifier'),
        secret=pulumi.get(__response__, 'secret'),
        triggers=pulumi.get(__response__, 'triggers'),
        url=pulumi.get(__response__, 'url')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSecurityGovernanceConditionResult',
    'AwaitableGetSecurityGovernanceConditionResult',
    'get_security_governance_condition',
    'get_security_governance_condition_output',
]

@pulumi.output_type
class GetSecurityGovernanceConditionResult:
    """
    A collection of values returned by getSecurityGovernanceCondition.
    """
    def __init__(__self__, description=None, fault_specs=None, id=None, infra_type=None, k8s_specs=None, machine_specs=None, name=None, org_id=None, project_id=None, tags=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if fault_specs and not isinstance(fault_specs, list):
            raise TypeError("Expected argument 'fault_specs' to be a list")
        pulumi.set(__self__, "fault_specs", fault_specs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if infra_type and not isinstance(infra_type, str):
            raise TypeError("Expected argument 'infra_type' to be a str")
        pulumi.set(__self__, "infra_type", infra_type)
        if k8s_specs and not isinstance(k8s_specs, list):
            raise TypeError("Expected argument 'k8s_specs' to be a list")
        pulumi.set(__self__, "k8s_specs", k8s_specs)
        if machine_specs and not isinstance(machine_specs, list):
            raise TypeError("Expected argument 'machine_specs' to be a list")
        pulumi.set(__self__, "machine_specs", machine_specs)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the security governance condition
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="faultSpecs")
    def fault_specs(self) -> Sequence['outputs.GetSecurityGovernanceConditionFaultSpecResult']:
        """
        Fault specification for the condition
        """
        return pulumi.get(self, "fault_specs")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the security governance condition. Either `id` or `name` must be specified.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="infraType")
    def infra_type(self) -> _builtins.str:
        """
        The infrastructure type (KubernetesV2, Linux, Windows)
        """
        return pulumi.get(self, "infra_type")

    @_builtins.property
    @pulumi.getter(name="k8sSpecs")
    def k8s_specs(self) -> Sequence['outputs.GetSecurityGovernanceConditionK8sSpecResult']:
        """
        Kubernetes specific configuration
        """
        return pulumi.get(self, "k8s_specs")

    @_builtins.property
    @pulumi.getter(name="machineSpecs")
    def machine_specs(self) -> Sequence['outputs.GetSecurityGovernanceConditionMachineSpecResult']:
        """
        Machine specific configuration
        """
        return pulumi.get(self, "machine_specs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the security governance condition. Either `id` or `name` must be specified.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        The organization ID of the security governance condition
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        The project ID of the security governance condition
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags associated with the condition
        """
        return pulumi.get(self, "tags")


class AwaitableGetSecurityGovernanceConditionResult(GetSecurityGovernanceConditionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityGovernanceConditionResult(
            description=self.description,
            fault_specs=self.fault_specs,
            id=self.id,
            infra_type=self.infra_type,
            k8s_specs=self.k8s_specs,
            machine_specs=self.machine_specs,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags)


def get_security_governance_condition(id: Optional[_builtins.str] = None,
                                      name: Optional[_builtins.str] = None,
                                      org_id: Optional[_builtins.str] = None,
                                      project_id: Optional[_builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityGovernanceConditionResult:
    """
    Data source for retrieving a Harness Chaos Security Governance Condition

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Example of looking up a security governance condition by name
    by_name = harness.chaos.get_security_governance_condition(org_id=org_id,
        project_id=project_id,
        name="k8s-security-condition")
    # Example of looking up a security governance condition by ID
    by_id = harness.chaos.get_security_governance_condition(org_id=org_id,
        project_id=project_id,
        id="<condition_id>")
    pulumi.export("securityGovernanceConditionByName", by_name)
    pulumi.export("securityGovernanceConditionById", by_id)
    ```


    :param _builtins.str id: The ID of the security governance condition. Either `id` or `name` must be specified.
    :param _builtins.str name: The name of the security governance condition. Either `id` or `name` must be specified.
    :param _builtins.str org_id: The organization ID of the security governance condition
    :param _builtins.str project_id: The project ID of the security governance condition
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:chaos/getSecurityGovernanceCondition:getSecurityGovernanceCondition', __args__, opts=opts, typ=GetSecurityGovernanceConditionResult).value

    return AwaitableGetSecurityGovernanceConditionResult(
        description=pulumi.get(__ret__, 'description'),
        fault_specs=pulumi.get(__ret__, 'fault_specs'),
        id=pulumi.get(__ret__, 'id'),
        infra_type=pulumi.get(__ret__, 'infra_type'),
        k8s_specs=pulumi.get(__ret__, 'k8s_specs'),
        machine_specs=pulumi.get(__ret__, 'machine_specs'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_security_governance_condition_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityGovernanceConditionResult]:
    """
    Data source for retrieving a Harness Chaos Security Governance Condition

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Example of looking up a security governance condition by name
    by_name = harness.chaos.get_security_governance_condition(org_id=org_id,
        project_id=project_id,
        name="k8s-security-condition")
    # Example of looking up a security governance condition by ID
    by_id = harness.chaos.get_security_governance_condition(org_id=org_id,
        project_id=project_id,
        id="<condition_id>")
    pulumi.export("securityGovernanceConditionByName", by_name)
    pulumi.export("securityGovernanceConditionById", by_id)
    ```


    :param _builtins.str id: The ID of the security governance condition. Either `id` or `name` must be specified.
    :param _builtins.str name: The name of the security governance condition. Either `id` or `name` must be specified.
    :param _builtins.str org_id: The organization ID of the security governance condition
    :param _builtins.str project_id: The project ID of the security governance condition
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:chaos/getSecurityGovernanceCondition:getSecurityGovernanceCondition', __args__, opts=opts, typ=GetSecurityGovernanceConditionResult)
    return __ret__.apply(lambda __response__: GetSecurityGovernanceConditionResult(
        description=pulumi.get(__response__, 'description'),
        fault_specs=pulumi.get(__response__, 'fault_specs'),
        id=pulumi.get(__response__, 'id'),
        infra_type=pulumi.get(__response__, 'infra_type'),
        k8s_specs=pulumi.get(__response__, 'k8s_specs'),
        machine_specs=pulumi.get(__response__, 'machine_specs'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))
